@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.0901'; 
+our $VERSION = '1.0902'; 
 $VERSION = eval $VERSION;
 
 use strict;
@@ -314,6 +314,12 @@ sub api_json_request {
 
     my $info   = $API[$api] || croak "Unknown API: $api";
     my ($method, $path) = @$info;
+	#if ($param{test}) {
+	#	use Data::Dump::Color;
+	#	dd $path;
+	#	dd @$args;
+	#	dd %param;
+	#}
     $path = sprintf $path, @$args;
 
     my ($query, $post_data);
@@ -589,8 +595,8 @@ sub get_subreddit_comments {
 	else 			  { $query->{limit} = DEFAULT_LIMIT;	    }
 
 	$subreddit = subreddit($subreddit); # remove slashes and leading r/
-    	my $args = [$view];
-    	unshift @$args, $subreddit if $subreddit;
+    	#my $args = [$view]; # this did nothing
+    	my $args = $subreddit ? [$subreddit] : [];
 
     	my $result = $self->api_json_request(
         	api      => ($subreddit ? API_COMMENTS : API_COMMENTS_FRONT),
